@@ -1,5 +1,5 @@
 package HTTP::Body::XForms;
-$HTTP::Body::XForms::VERSION = '1.22';
+$HTTP::Body::XForms::VERSION = '1.23';
 use strict;
 use base 'HTTP::Body';
 use bytes;
@@ -47,6 +47,10 @@ sub spin {
 
 =back
 
+=head1 SUPPORT
+
+See L<HTTP::Body>
+
 =head1 AUTHOR
 
 Daniel Ruoso, C<daniel@ruoso.com>
